@@ -5,7 +5,6 @@
 # yanto : 730988759
 # kenkan : 1607338903
 # kyy : 1663258664
-# rizz : 951454060
 
 DEVS = [
     1191668125,
@@ -15,7 +14,6 @@ DEVS = [
     730988759,
     1607338903,
     1663258664,
-    951454060,
     901878554,
 ]
 
@@ -38,6 +36,7 @@ DEVS = [
 # android apk : -1001212593743
 # bruno : -1001084578942
 # aot : -1001070335805
+# telegram bot : -1001311056733
 
 GROUP = [
     -1001387666944, # pyrogram 
@@ -56,5 +55,6 @@ GROUP = [
     -1001256902287, # durov
     -1001212593743, # android apk
     -1001084578942, # bruno support
-    -1001070335805, # aot 
+    -1001070335805, # aot
+    -1001311056733, # telegram bot
 ]
